@@ -5,6 +5,9 @@ mod server;
 mod token;
 mod util;
 
+#[cfg(test)]
+mod test;
+
 pub use client::*;
 pub use server::*;
 pub use token::*;
